﻿using Android.App;
using Android.Content;
using Android.OS;
using AndroidX.Core.App;
using Java.Lang;

namespace BackgroundSV
{
    [Service(ForegroundServiceType = Android.Content.PM.ForegroundService.TypeDataSync)]
    public class BackgroundService : Service
    {
        private const int ServiceId = 1001;
        private const string ChannelId = "background_service_channel";
        private bool isRunning;

        public override IBinder OnBind(Intent intent)
        {
            return null;
        }

        public override StartCommandResult OnStartCommand(Intent intent, StartCommandFlags flags, int startId)
        {
            if (!isRunning)
            {
                isRunning = true;
                StartForegroundService();
            }

            return StartCommandResult.Sticky;
        }

        private void StartForegroundService()
        {
            // Create a notification channel for Android 8.0 and higher
            CreateNotificationChannel();

            // Build the notification
            var notification = new NotificationCompat.Builder(this, ChannelId)
                .SetContentTitle("Background Service")
                .SetContentText("Service is running...")
                .SetSmallIcon(Resource.Drawable.material_ic_menu_arrow_down_black_24dp) // Use your app's foreground icon
                .SetOngoing(true)
                .Build();

            // Start the service in the foreground
            StartForeground(ServiceId, notification);

            // Simulate background work
            new Java.Lang.Thread(() =>
            {
                while (isRunning)
                {
                    // Update the notification with the current time
                    var updatedNotification = new NotificationCompat.Builder(this, ChannelId)
                        .SetContentTitle("Background Service")
                        .SetContentText($"Current time: {JavaSystem.CurrentTimeMillis()}")
                        .SetSmallIcon(Resource.Drawable.material_ic_menu_arrow_down_black_24dp)
                        .SetOngoing(true)
                        .Build();

                    NotificationManagerCompat.From(this).Notify(ServiceId, updatedNotification);

                    // Wait for 1 second
                    Java.Lang.Thread.Sleep(1000);
                }
            }).Start();
        }

        private void CreateNotificationChannel()
        {
            if (Build.VERSION.SdkInt >= BuildVersionCodes.O)
            {
                var channel = new NotificationChannel(
                    ChannelId,
                    "Background Service Channel",
                    NotificationImportance.Default);

                var manager = GetSystemService(NotificationService) as NotificationManager;
                manager.CreateNotificationChannel(channel);
            }
        }

        public override void OnDestroy()
        {
            isRunning = false;
            base.OnDestroy();
        }
    }
}
